@@ -187,11 +187,11 @@ Will match exactly the C<model> field.
 
 =item os
 
-Will match exactly the C<os> field, which is the operating sytem.
+Will match exactly the C<os> field, which is the operating system.
 
 =item os_ver
 
-Will match exactly the C<os_ver> field, which is the operating sytem software version.
+Will match exactly the C<os_ver> field, which is the operating system software version.
 
 =item vendor
 
@@ -226,21 +226,20 @@ sub search_by_field {
     }
 
     # For Search on Layers
-    my @layer_search = ( '_', '_', '_', '_', '_', '_', '_' );
-    # @layer_search is computer indexed, left->right
     my $layers = $p->{layers};
+    my @layer_select = ();
     if ( defined $layers && ref $layers ) {
       foreach my $layer (@$layers) {
         next unless defined $layer and length($layer);
         next if ( $layer < 1 || $layer > 7 );
-        $layer_search[ $layer - 1 ] = 1;
+        push @layer_select,
+          \[ 'substring(me.layers,9-?, 1)::int = 1', $layer ];
       }
     }
     elsif ( defined $layers ) {
-      $layer_search[ $layers - 1 ] = 1;
+      push @layer_select,
+        \[ 'substring(me.layers,9-?, 1)::int = 1', $layers ];
     }
-    # the database field is in order 87654321
-    my $layer_string = join( '', reverse @layer_search );
 
     return $rs
       ->search_rs({}, $attrs)
@@ -252,8 +251,6 @@ sub search_by_field {
             { '-ilike' => "\%$p->{location}\%" }) : ()),
           ($p->{description} ? ('me.description' =>
             { '-ilike' => "\%$p->{description}\%" }) : ()),
-          ($p->{layers} ? ('me.layers' =>
-            { '-ilike' => "\%$layer_string" }) : ()),
 
           ($p->{model} ? ('me.model' =>
             { '-in' => $p->{model} }) : ()),
@@ -264,6 +261,8 @@ sub search_by_field {
           ($p->{vendor} ? ('me.vendor' =>
             { '-in' => $p->{vendor} }) : ()),
 
+          ($p->{layers} ? (-or => \@layer_select) : ()),
+
           ($p->{dns} ? (
             -or => [
               'me.dns' => { '-ilike' => "\%$p->{dns}\%" },
